Credentials in URLs may be stored in different places, including the user's device, the web server, and any forward or
reverse proxy servers between the two endpoints. URLs may also be displayed on-screen, bookmarked or emailed around by
users. They may be disclosed to third parties via the Referer header when any off-site links are followed. Placing
session tokens into the URL increases the risk that they will be captured by an attacker.